@@ -1,4 +1,4 @@
-/* $Id: procsignal.h,v 1.24 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: procsignal.h,v 1.26 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -42,7 +42,7 @@ typedef struct _glibtop_proc_signal	glibtop_proc_signal;
 
 struct _glibtop_proc_signal
 {
-	u_int64_t	flags,
+	guint64	flags,
 		signal [2],		/* mask of pending signals */
 		blocked [2],		/* mask of blocked signals */
 		sigignore [2],		/* mask of ignored signals */
@@ -67,16 +67,6 @@ void glibtop_init_proc_signal_s (glibtop *server);
 void glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_signal [];
-extern const unsigned glibtop_types_proc_signal [];
-extern const char *glibtop_labels_proc_signal [];
-extern const char *glibtop_descriptions_proc_signal [];
-
-#endif
 
 G_END_DECLS
 
