@@ -1,4 +1,4 @@
-/* $Id: procuid.h,v 1.26 2004/06/18 07:38:37 bdejean Exp $ */
+/* $Id: procuid.h,v 1.27 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -98,16 +98,6 @@ void glibtop_init_proc_uid_s (glibtop *server);
 void glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_uid [];
-extern const unsigned glibtop_types_proc_uid [];
-extern const char *glibtop_labels_proc_uid [];
-extern const char *glibtop_descriptions_proc_uid [];
-
-#endif
 
 G_END_DECLS
 
