@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.24 2003/12/23 10:44:33 hadess Exp $ */
+/* $Id: swap.c,v 1.28.2.1 2005/06/13 09:09:51 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -25,13 +25,15 @@
 #include <glibtop/error.h>
 #include <glibtop/swap.h>
 
+#include "glibtop_private.h"
+
 #include <fcntl.h>
 
-static unsigned long _glibtop_sysdeps_swap =
+static const unsigned long _glibtop_sysdeps_swap =
 (1L << GLIBTOP_SWAP_TOTAL) + (1L << GLIBTOP_SWAP_USED) +
 (1L << GLIBTOP_SWAP_FREE);
 
-static unsigned long _glibtop_sysdeps_swap_paging =
+static const unsigned long _glibtop_sysdeps_swap_paging =
 (1L << GLIBTOP_SWAP_PAGEIN) + (1L << GLIBTOP_SWAP_PAGEOUT);
 
 /* Init function. */
@@ -47,56 +49,59 @@ glibtop_init_swap_s (glibtop *server)
 
 #define MEMINFO		"/proc/meminfo"
 #define PROC_STAT	"/proc/stat"
+#define PROC_VMSTAT	"/proc/vmstat"
 
 void
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 {
 	char buffer [BUFSIZ], *p;
-	int fd, len;
 
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SWAP, 0);
 
 	memset (buf, 0, sizeof (glibtop_swap));
 
-	fd = open (MEMINFO, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", MEMINFO);
-
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", MEMINFO);
-
-	close (fd);
-
-	buffer [len] = '\0';
+	file_to_buffer(server, buffer, MEMINFO);
 
 	/* Kernel 2.6 with multiple lines */
- 
+
 	buf->total = get_scaled(buffer, "SwapTotal:");
 	buf->free = get_scaled(buffer, "SwapFree:");
 	buf->used = buf->total - buf->free;
 
 	buf->flags = _glibtop_sysdeps_swap;
 
-	fd = open (PROC_STAT, O_RDONLY);
-	if (fd < 0)
-		glibtop_error_io_r (server, "open (%s)", PROC_STAT);
 
-	len = read (fd, buffer, BUFSIZ-1);
-	if (len < 0)
-		glibtop_error_io_r (server, "read (%s)", PROC_STAT);
+	if(server->os_version_code >= LINUX_VERSION_CODE(2, 6, 0))
+	{
+		file_to_buffer (server, buffer, PROC_VMSTAT);
 
-	close (fd);
+		p = strstr (buffer, "\npswpin");
 
-	buffer [len] = '\0';
+		if(p)
+		{
+			p = skip_token(p);
+			buf->pagein  = strtoull (p, &p, 0);
 
-	p = strstr (buffer, "\nswap");
-	if (p == NULL) return;
+			p = skip_token(p);
+			buf->pageout  = strtoull (p, &p, 0);
 
-	p = skip_token (p);
+			buf->flags |= _glibtop_sysdeps_swap_paging;
+		}
+	}
+	else /* Linux 2.4 */
+	{
+		file_to_buffer (server, buffer, PROC_STAT);
 
-	buf->pagein  = strtoull (p, &p, 0);
-	buf->pageout = strtoull (p, &p, 0);
+		p = strstr (buffer, "\nswap");
 
-	buf->flags |= _glibtop_sysdeps_swap_paging;
+		if(p)
+		{
+			p = skip_token (p);
+
+			buf->pagein  = strtoull (p, &p, 0);
+			buf->pageout = strtoull (p, &p, 0);
+
+			buf->flags |= _glibtop_sysdeps_swap_paging;
+		}
+	}
 }
